@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -100,7 +88,7 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
+        KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
         KIMAP::SearchJob *job = new KIMAP::SearchJob(&session);
         job->setUidBased(uidbased);
@@ -137,7 +125,7 @@ private Q_SLOTS:
                      << "S: * SEARCH 10 12"
                      << "S: A000001 OK search done";
 
-            QTest::newRow("uidbased header search") << scenario << true << 2 << KIMAP::Term(QLatin1String("Message-Id"), QLatin1String("<12345678@mail.box>"));
+            QTest::newRow("uidbased header search") << scenario << true << 2 << KIMAP::Term(QStringLiteral("Message-Id"), QStringLiteral("<12345678@mail.box>"));
         }
         {
             QList<QByteArray> scenario;
@@ -146,7 +134,7 @@ private Q_SLOTS:
                      << "S: * SEARCH"
                      << "S: A000001 OK search done";
 
-            QTest::newRow("OR search with no results") << scenario << false << 0 << KIMAP::Term(KIMAP::Term::Or, QVector<KIMAP::Term>() << KIMAP::Term(KIMAP::Term::New) << KIMAP::Term(QLatin1String("Message-Id"), QLatin1String("<12345678@mail.box>")));
+            QTest::newRow("OR search with no results") << scenario << false << 0 << KIMAP::Term(KIMAP::Term::Or, QVector<KIMAP::Term>() << KIMAP::Term(KIMAP::Term::New) << KIMAP::Term(QStringLiteral("Message-Id"), QStringLiteral("<12345678@mail.box>")));
         }
         {
             QList<QByteArray> scenario;
@@ -154,7 +142,7 @@ private Q_SLOTS:
                      << "C: A000001 SEARCH TO \"<testuser@kde.testserver>\""
                      << "S: * SEARCH 1"
                      << "S: A000001 OK search done";
-            QTest::newRow("literal data search") << scenario << false << 1 << KIMAP::Term(KIMAP::Term::To, QLatin1String("<testuser@kde.testserver>"));
+            QTest::newRow("literal data search") << scenario << false << 1 << KIMAP::Term(KIMAP::Term::To, QStringLiteral("<testuser@kde.testserver>"));
         }
         {
             QList<QByteArray> scenario;
@@ -164,6 +152,19 @@ private Q_SLOTS:
                      << "S: A000001 OK search done";
             QTest::newRow("uidbased NOT NEW search") << scenario << true << 6 << KIMAP::Term(KIMAP::Term::New).setNegated(true);
         }
+
+        {
+            QList<QByteArray> scenario;
+            scenario << FakeServer::preauth()
+                     << "C: A000001 UID SEARCH OR HEADER Message-Id \"<1234567@mail.box>\" (OR HEADER Message-Id \"<7654321@mail.box>\" (OR HEADER Message-Id \"<abcdefg@mail.box>\" HEADER Message-Id \"<gfedcba@mail.box>\"))"
+                     << "S: * SEARCH 1 2 3 4"
+                     << "S: A000001 OK search done";
+            KIMAP::Term term{KIMAP::Term::Or, {KIMAP::Term{QStringLiteral("Message-Id"), QStringLiteral("<1234567@mail.box>")},
+                                               KIMAP::Term{QStringLiteral("Message-Id"), QStringLiteral("<7654321@mail.box>")},
+                                               KIMAP::Term{QStringLiteral("Message-Id"), QStringLiteral("<abcdefg@mail.box>")},
+                                               KIMAP::Term{QStringLiteral("Message-Id"), QStringLiteral("<gfedcba@mail.box>")}}};
+            QTest::newRow("OR with multiple subterms") << scenario << true << 4 << term;
+        }
     }
 
     void testSearchTerm()
@@ -177,7 +178,7 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
+        KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
         KIMAP::SearchJob *job = new KIMAP::SearchJob(&session);
         job->setUidBased(uidbased);
