@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "fetchjob.h"
@@ -58,25 +45,25 @@ public:
         Q_EMIT q->messagesAvailable(pendingMsgs);
 
         if (!pendingParts.isEmpty()) {
-            emit q->partsReceived(selectedMailBox,
+            Q_EMIT q->partsReceived(selectedMailBox,
                                   pendingUids, pendingParts);
-            emit q->partsReceived(selectedMailBox,
+            Q_EMIT q->partsReceived(selectedMailBox,
                                   pendingUids, pendingAttributes,
                                   pendingParts);
         }
         if (!pendingSizes.isEmpty() || !pendingFlags.isEmpty() || !pendingMessages.isEmpty()) {
-            emit q->headersReceived(selectedMailBox,
+            Q_EMIT q->headersReceived(selectedMailBox,
                                     pendingUids, pendingSizes,
                                     pendingFlags, pendingMessages);
-            emit q->headersReceived(selectedMailBox,
+            Q_EMIT q->headersReceived(selectedMailBox,
                                     pendingUids, pendingSizes,
                                     pendingAttributes, pendingFlags,
                                     pendingMessages);
         }
         if (!pendingMessages.isEmpty()) {
-            emit q->messagesReceived(selectedMailBox,
+            Q_EMIT q->messagesReceived(selectedMailBox,
                                      pendingUids, pendingMessages);
-            emit q->messagesReceived(selectedMailBox,
+            Q_EMIT q->messagesReceived(selectedMailBox,
                                      pendingUids, pendingAttributes,
                                      pendingMessages);
         }
@@ -133,7 +120,7 @@ FetchJob::~FetchJob()
 void FetchJob::setSequenceSet(const ImapSet &set)
 {
     Q_D(FetchJob);
-    Q_ASSERT(!set.toImapSequenceSet().trimmed().isEmpty());
+    Q_ASSERT(!set.isEmpty());
     d->set = set;
 }
 
@@ -189,6 +176,7 @@ void FetchJob::doStart()
 {
     Q_D(FetchJob);
 
+    d->set.optimize();
     QByteArray parameters = d->set.toImapSequenceSet() + ' ';
     Q_ASSERT(!parameters.trimmed().isEmpty());
 
