@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "idlejob.h"
@@ -42,7 +29,7 @@ public:
     {
         emitStatsTimer.stop();
 
-        emit q->mailBoxStats(q, m_session->selectedMailBox(),
+        Q_EMIT q->mailBoxStats(q, m_session->selectedMailBox(),
                              messageCount, recentCount);
 
         lastMessageCount = messageCount;
@@ -107,7 +94,7 @@ void IdleJob::handleResponse(const Response &response)
 {
     Q_D(IdleJob);
 
-    // We can predict it'll be handled by handleErrorReplies() so emit
+    // We can predict it'll be handled by handleErrorReplies() so Q_EMIT
     // pending signals now (if needed) so that result() will really be
     // the last emitted signal.
     if (!response.content.isEmpty() &&
