@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "imapset.h"
@@ -316,6 +303,38 @@ bool ImapSet::isEmpty() const
     return d->intervals.isEmpty();
 }
 
+void ImapSet::optimize()
+{
+    // There's nothing to optimize if we have fewer than 2 intervals
+    if (d->intervals.size() < 2) {
+        return;
+    }
+
+    // Sort the intervals in ascending order by their beginning value
+    std::sort(d->intervals.begin(), d->intervals.end(),
+              [](const ImapInterval &lhs, const ImapInterval &rhs) {
+                   return lhs.begin() < rhs.begin();
+              });
+
+    auto it = d->intervals.begin();
+    while (it != d->intervals.end() && it != std::prev(d->intervals.end())) {
+        auto next = std::next(it);
+        // +1 so that we also merge neighbouring intervals, e.g. 1:2,3:4 -> 1:4
+        if (it->hasDefinedEnd() && it->end() + 1 >= next->begin()) {
+            next->setBegin(it->begin());
+            if (next->hasDefinedEnd() && it->end() > next->end()) {
+                next->setEnd(it->end());
+            }
+            it = d->intervals.erase(it);
+        } else if (!it->hasDefinedEnd()) {
+            // We can eat up all the remaining intervals
+            it = d->intervals.erase(next, d->intervals.end());
+        } else {
+            ++it;
+        }
+    }
+}
+
 QDebug &operator<<(QDebug &d, const ImapInterval &interval)
 {
     d << interval.toImapSequence();
