@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIMAP_LISTJOB_H
@@ -62,16 +49,16 @@ public:
     };
 
     explicit ListJob(Session *session);
-    virtual ~ListJob();
+    ~ListJob() override;
 
     KIMAP_DEPRECATED void setIncludeUnsubscribed(bool include);
     KIMAP_DEPRECATED bool isIncludeUnsubscribed() const;
 
     void setOption(Option option);
-    Option option() const;
+    Q_REQUIRED_RESULT Option option() const;
 
     void setQueriedNamespaces(const QList<MailBoxDescriptor> &namespaces);
-    QList<MailBoxDescriptor> queriedNamespaces() const;
+    Q_REQUIRED_RESULT QList<MailBoxDescriptor> queriedNamespaces() const;
 
     KIMAP_DEPRECATED QList<MailBoxDescriptor> mailBoxes() const;
     KIMAP_DEPRECATED QMap< MailBoxDescriptor, QList<QByteArray> > flags() const;
