@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Andras Mantia <amantia@kde.org>
+    SPDX-FileCopyrightText: 2009 Andras Mantia <amantia@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIMAP_QUOTAJOBBASE_H
@@ -35,7 +22,7 @@ class QuotaJobBasePrivate;
  * Base class for jobs that operate on mailbox quotas
  *
  * Provides support for the IMAP QUOTA extension, as defined by
- * <a href="http://www.apps.ietf.org/rfc/rfc2087.html" title="IMAP QUOTA extension">RFC 2087</a>.
+ * <a href="https://tools.ietf.org/html/rfc2087" title="IMAP QUOTA extension">RFC 2087</a>.
  *
  * This class cannot be used directly, you must subclass it and reimplement
  * at least the doStart() method.
