@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Andras Mantia <amantia@kde.org>
+    SPDX-FileCopyrightText: 2009 Andras Mantia <amantia@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "searchjob.h"
@@ -69,25 +56,24 @@ Term::Term(Term::Relation relation, const QVector<Term> &subterms)
     :  d(new Term::Private)
 {
     if (subterms.size() >= 2) {
-        d->command += "(";
         if (relation == KIMAP::Term::Or) {
-            d->command += "OR ";
-            d->command += subterms.at(0).serialize() + ' ';
-            if (subterms.size() >= 3) {
-                Term t(relation, subterms.mid(1));
-                d->command += t.serialize();
-            } else if (subterms.size() == 2) {
-                d->command += subterms.at(1).serialize();
+            for (int i = 0; i < subterms.size() - 1; ++i) {
+                d->command += "(OR " + subterms[i].serialize() + " ";
+            }
+            d->command += subterms.back().serialize();
+            for (int i = 0; i < subterms.size() - 1; ++i) {
+                d->command += ")";
             }
         } else {
+            d->command += "(";
             for (const Term &t : subterms) {
                 d->command += t.serialize() + ' ';
             }
             if (!subterms.isEmpty()) {
                 d->command.chop(1);
             }
+            d->command += ")";
         }
-        d->command += ")";
     } else if (subterms.size() == 1) {
         d->command += subterms.first().serialize();
     } else {
@@ -231,7 +217,9 @@ Term::Term(Term::SequenceSearchKey key, const ImapSet &set)
     case SequenceNumber:
         break;
     }
-    d->command += " " + set.toImapSequenceSet();
+    auto optimizedSet = set;
+    optimizedSet.optimize();
+    d->command += " " + optimizedSet.toImapSequenceSet();
 }
 
 Term::Term(const Term &other)
